==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property virtualServiceName Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
 */
public data class GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs(
    public val virtualServiceName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs> {
    override fun toJava():
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.builder()
            .virtualServiceName(virtualServiceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder internal constructor() {
    private var virtualServiceName: Output<String>? = null

    /**
     * @param value Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
     */
    @JvmName("ppmcsrmcmnpliban")
    public suspend fun virtualServiceName(`value`: Output<String>) {
        this.virtualServiceName = value
    }

    /**
     * @param value Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
     */
    @JvmName("owkvwtdwkyrjhoke")
    public suspend fun virtualServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualServiceName = mapped
    }

    internal fun build(): GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs =
        GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs(
            virtualServiceName = virtualServiceName ?: throw PulumiNullFieldException("virtualServiceName"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property virtualServiceName Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
 */
public data class GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs(
    public val virtualServiceName: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs =
        com.pulumi.aws.appmesh.inputs.GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs.builder()
            .virtualServiceName(virtualServiceName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs].
 */
@PulumiTagMarker
public class GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgsBuilder internal constructor() {
    private var virtualServiceName: Output<String>? = null

    /**
     * @param value Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
     */
    @JvmName("godjsclkmjweboom")
    public suspend fun virtualServiceName(`value`: Output<String>) {
        this.virtualServiceName = value
    }

    /**
     * @param value Name of the virtual service that traffic is routed to. Must be between 1 and 255 characters in length.
     */
    @JvmName("huslrsonefvlmecs")
    public suspend fun virtualServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualServiceName = mapped
    }

    internal fun build(): GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs =
        GatewayRouteSpecGrpcRouteActionTargetVirtualServiceArgs(
            virtualServiceName = virtualServiceName ?: throw PulumiNullFieldException("virtualServiceName"),
        )
}
